==> haskell-atomic-primops-0.8.4-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-atomic-primops.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 atomic-primops
version:              0.8.4
visibility:           public
id:                   atomic-primops-0.8.4-DlpmXqPVpBPpHZxNGQOoX
key:                  atomic-primops-0.8.4-DlpmXqPVpBPpHZxNGQOoX
license:              BSD-3-Clause
maintainer:           rrnewton@gmail.com
author:               Ryan Newton
homepage:             https://github.com/rrnewton/haskell-lockfree/wiki
synopsis:             A safe approach to CAS and other atomic ops in Haskell.
description:
    After GHC 7.4 a new `casMutVar#` primop became available, but it'\''s
    difficult to use safely, because pointer equality is a highly
    unstable property in Haskell.  This library provides a safer method
    based on the concept of "Tickets".

    Also, this library uses the "foreign primop" capability of GHC to
    add access to other variants that may be of
    interest, specifically, compare and swap inside an array.

    Note that as of GHC 7.8, the relevant primops have been included in GHC itself.
    This library is engineered to work pre- and post-GHC-7.8, while exposing the
    same interface.

category:             Data
abi:                  ca334b5c22d80d710b7759a485777b50
exposed:              True
exposed-modules:
    Data.Atomics Data.Atomics.Counter Data.Atomics.Internal

import-dirs:          /usr/lib/ghc-8.10.4/site-local/atomic-primops-0.8.4
library-dirs:         /usr/lib/ghc-8.10.4/site-local/atomic-primops-0.8.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/atomic-primops-0.8.4
hs-libraries:         HSatomic-primops-0.8.4-DlpmXqPVpBPpHZxNGQOoX
depends:
    base-4.14.1.0 ghc-prim-0.6.1
    primitive-0.7.1.0-4basvdNEktJ1IOTknZqeFm

haddock-interfaces:
    /usr/share/doc/haskell-atomic-primops/html/atomic-primops.haddock

haddock-html:         /usr/share/doc/haskell-atomic-primops/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-atomic-primops-0.8.4-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-atomic-primops.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 atomic-primops
version:              0.8.4
visibility:           public
id:                   atomic-primops-0.8.4-74fPvhDxYALEytIZFna7qg
key:                  atomic-primops-0.8.4-74fPvhDxYALEytIZFna7qg
license:              BSD-3-Clause
maintainer:           rrnewton@gmail.com
author:               Ryan Newton
homepage:             https://github.com/rrnewton/haskell-lockfree/wiki
synopsis:             A safe approach to CAS and other atomic ops in Haskell.
description:
    After GHC 7.4 a new `casMutVar#` primop became available, but it'\''s
    difficult to use safely, because pointer equality is a highly
    unstable property in Haskell.  This library provides a safer method
    based on the concept of "Tickets".

    Also, this library uses the "foreign primop" capability of GHC to
    add access to other variants that may be of
    interest, specifically, compare and swap inside an array.

    Note that as of GHC 7.8, the relevant primops have been included in GHC itself.
    This library is engineered to work pre- and post-GHC-7.8, while exposing the
    same interface.

category:             Data
abi:                  a955ecb923f68c5a9240264c841d2ba7
exposed:              True
exposed-modules:
    Data.Atomics Data.Atomics.Counter Data.Atomics.Internal

import-dirs:          /usr/lib/ghc-8.10.4/site-local/atomic-primops-0.8.4
library-dirs:         /usr/lib/ghc-8.10.4/site-local/atomic-primops-0.8.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/atomic-primops-0.8.4
hs-libraries:         HSatomic-primops-0.8.4-74fPvhDxYALEytIZFna7qg
depends:
    base-4.14.1.0 ghc-prim-0.6.1
    primitive-0.7.1.0-E4X9CCBanM6KFkbtZATozp

haddock-interfaces:
    /usr/share/doc/haskell-atomic-primops/html/atomic-primops.haddock

haddock-html:         /usr/share/doc/haskell-atomic-primops/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
